@@ -9,7 +9,6 @@ describe 'rally::db' do
         :db_max_retries          => '<SERVICE DEFAULT>',
         :connection              => 'sqlite:////var/lib/rally/rally.sqlite',
         :connection_recycle_time => '<SERVICE DEFAULT>',
-        :min_pool_size           => '<SERVICE DEFAULT>',
         :max_pool_size           => '<SERVICE DEFAULT>',
         :max_retries             => '<SERVICE DEFAULT>',
         :retry_interval          => '<SERVICE DEFAULT>',
@@ -31,7 +30,6 @@ describe 'rally::db' do
         {
           :database_connection              => 'mysql://rally:rally@localhost/rally',
           :database_connection_recycle_time => '3601',
-          :database_min_pool_size           => '2',
           :database_max_retries             => '11',
           :database_retry_interval          => '11',
           :database_max_pool_size           => '11',
@@ -47,7 +45,6 @@ describe 'rally::db' do
         :db_max_retries          => '-1',
         :connection              => 'mysql://rally:rally@localhost/rally',
         :connection_recycle_time => '3601',
-        :min_pool_size           => '2',
         :max_pool_size           => '11',
         :max_retries             => '11',
         :retry_interval          => '11',
